CreatureCounter class

Constructors

CreatureCounter({required TickerProvider vsync, required List<Color> initialColors, required int initialCounter, BlendMode blend = BlendMode.hardLight})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
decrementCounter() → void
getCounter() → int?
incrementCounter() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited